@@ -28,6 +28,7 @@ from awkward._typing import (
     Any,
     Callable,
     Final,
+    Literal,
     Self,
     SupportsIndex,
     final,
@@ -269,7 +270,7 @@ class IndexedOptionArray(IndexedOptionMeta[Content], Content):
             return self
         else:
             return IndexedOptionArray(
-                self._backend.nplike.astype(self._index, dtype=np.int64),
+                self._index.to64(),
                 self._content,
                 parameters=self._parameters,
             )
@@ -342,6 +343,11 @@ class IndexedOptionArray(IndexedOptionMeta[Content], Content):
             self._touch_shape(recursive=False)
             return self
 
+        # in non-typetracer mode (and if all lengths are known) we can check if the slice is a no-op
+        # (i.e. slicing the full array) and shortcut to avoid noticeable python overhead
+        if self._backend.nplike.known_data and (start == 0 and stop == self.length):
+            return self
+
         return IndexedOptionArray(
             self._index[start:stop], self._content, parameters=self._parameters
         )
@@ -498,9 +504,9 @@ class IndexedOptionArray(IndexedOptionMeta[Content], Content):
         elif is_integer_like(head) or isinstance(
             head, (slice, ak.index.Index64, ak.contents.ListOffsetArray)
         ):
-            nexthead, nexttail = ak._slicing.head_tail(tail)
+            _nexthead, _nexttail = ak._slicing.head_tail(tail)
 
-            numnull, nextcarry, outindex = self._nextcarry_outindex()
+            _numnull, nextcarry, outindex = self._nextcarry_outindex()
 
             next = self._content._carry(nextcarry, True)
             out = next._getitem_next(head, tail, advanced)
@@ -643,15 +649,22 @@ class IndexedOptionArray(IndexedOptionMeta[Content], Content):
                 )
                 return (outoffsets, flattened)
 
-    def _mergeable_next(self, other: Content, mergebool: bool) -> bool:
+    def _mergeable_next(
+        self,
+        other: Content,
+        mergebool: bool,
+        mergecastable: Literal["same_kind", "equiv", "family"],
+    ) -> bool:
         # Is the other content is an identity, or a union?
         if other.is_identity_like or other.is_union:
             return True
         # Is the other array indexed or optional?
         elif other.is_option or other.is_indexed:
-            return self._content._mergeable_next(other.content, mergebool)
+            return self._content._mergeable_next(
+                other.content, mergebool, mergecastable
+            )
         else:
-            return self._content._mergeable_next(other, mergebool)
+            return self._content._mergeable_next(other, mergebool, mergecastable)
 
     def _merging_strategy(self, others):
         if len(others) == 0:
@@ -978,7 +991,7 @@ class IndexedOptionArray(IndexedOptionMeta[Content], Content):
 
         index_length = self._index.length
 
-        next, nextparents, numnull, outindex = self._rearrange_prepare_next(parents)
+        next, nextparents, _numnull, _outindex = self._rearrange_prepare_next(parents)
 
         out = next._unique(
             negaxis,
@@ -1252,7 +1265,7 @@ class IndexedOptionArray(IndexedOptionMeta[Content], Content):
         nulls_index_content = ak.contents.NumpyArray(
             nulls_index.data, parameters=None, backend=self._backend
         )
-        if out._mergeable_next(nulls_index_content, True):
+        if out._mergeable_next(nulls_index_content, True, "same_kind"):
             out = out._mergemany([nulls_index_content])
             nulls_merged = True
 
@@ -1335,7 +1348,7 @@ class IndexedOptionArray(IndexedOptionMeta[Content], Content):
         )
         branch, depth = self.branch_depth
 
-        next, nextparents, numnull, outindex = self._rearrange_prepare_next(parents)
+        next, nextparents, _numnull, outindex = self._rearrange_prepare_next(parents)
 
         out = next._sort_next(
             negaxis, starts, nextparents, outlength, ascending, stable
@@ -1394,7 +1407,7 @@ class IndexedOptionArray(IndexedOptionMeta[Content], Content):
     ):
         branch, depth = self.branch_depth
 
-        next, nextparents, numnull, outindex = self._rearrange_prepare_next(parents)
+        next, nextparents, _numnull, outindex = self._rearrange_prepare_next(parents)
 
         if reducer.needs_position and (not branch and negaxis == depth):
             nextshifts = self._rearrange_nextshifts(nextparents, shifts)
