@@ -1,24 +1,41 @@
-# BSD 3-Clause License; see https://github.com/scikit-hep/awkward-1.0/blob/main/LICENSE
-__all__ = ("pad_none",)
+# BSD 3-Clause License; see https://github.com/scikit-hep/awkward/blob/main/LICENSE
+
+from __future__ import annotations
+
 import awkward as ak
-from awkward._layout import wrap_layout
-from awkward._nplikes.numpylike import NumpyMetadata
+from awkward._dispatch import high_level_function
+from awkward._layout import HighLevelContext
+from awkward._namedaxis import (
+    _get_named_axis,
+    _named_axis_to_positional_axis,
+)
+from awkward._nplikes.numpy_like import NumpyMetadata
 from awkward._regularize import regularize_axis
 
+__all__ = ("pad_none",)
+
 np = NumpyMetadata.instance()
 
 
-def pad_none(array, target, axis=1, *, clip=False, highlevel=True, behavior=None):
+@high_level_function()
+def pad_none(
+    array, target, axis=1, *, clip=False, highlevel=True, behavior=None, attrs=None
+):
     """
     Args:
         array: Array-like data (anything #ak.to_layout recognizes).
         target (int): The intended length of the lists. If `clip=True`,
             the output lists will have exactly this length; otherwise,
             they will have *at least* this length.
-        axis (int): The dimension at which this operation is applied. The
+        axis (int or str): The dimension at which this operation is applied. The
             outermost dimension is `0`, followed by `1`, etc., and negative
             values count backward from the innermost: `-1` is the innermost
             dimension, `-2` is the next level up, etc.
+            If a str, it is interpreted as the name of the axis which maps
+            to an int if named axes are present. Named axes are attached
+            to an array using #ak.with_named_axis and removed with
+            #ak.without_named_axis; also see the
+            [Named axes user guide](../../user-guide/how-to-array-properties-named-axis.html).
         clip (bool): If True, the output lists will have regular lengths
             (#ak.types.RegularType) of exactly `target`; otherwise the
             output lists will have in-principle variable lengths
@@ -27,6 +44,8 @@ def pad_none(array, target, axis=1, *, clip=False, highlevel=True, behavior=None
             a low-level #ak.contents.Content subclass.
         behavior (None or dict): Custom #ak.behavior for the output array, if
             high-level.
+        attrs (None or dict): Custom attributes for the output array, if
+            high-level.
 
     Increase the lengths of lists to a target length by adding None values.
 
@@ -95,23 +114,23 @@ def pad_none(array, target, axis=1, *, clip=False, highlevel=True, behavior=None
         >>> ak.pad_none(array, 2, axis=2, clip=True).type.show()
         3 * var *   2 * ?float64
     """
-    with ak._errors.OperationErrorContext(
-        "ak.pad_none",
-        {
-            "array": array,
-            "target": target,
-            "axis": axis,
-            "clip": clip,
-            "highlevel": highlevel,
-            "behavior": behavior,
-        },
-    ):
-        return _impl(array, target, axis, clip, highlevel, behavior)
+    # Dispatch
+    yield (array,)
+
+    # Implementation
+    return _impl(array, target, axis, clip, highlevel, behavior, attrs)
 
 
-def _impl(array, target, axis, clip, highlevel, behavior):
-    axis = regularize_axis(axis)
-    layout = ak.operations.to_layout(array, allow_record=False, allow_other=False)
+def _impl(array, target, axis, clip, highlevel, behavior, attrs):
+    with HighLevelContext(behavior=behavior, attrs=attrs) as ctx:
+        layout = ctx.unwrap(array, allow_record=False, primitive_policy="error")
+
+    named_axis = _get_named_axis(ctx)
+    # Step 1: Normalize named axis to positional axis
+    axis = _named_axis_to_positional_axis(named_axis, axis)
+
+    axis = regularize_axis(axis, none_allowed=False)
+
     out = ak._do.pad_none(layout, target, axis, clip=clip)
 
-    return wrap_layout(out, behavior, highlevel, like=array)
+    return ctx.wrap(out, highlevel=highlevel)
